summary refs log tree commit diff
path: root/synapse/config/server.py
diff options
context:
space:
mode:
authorPatrick Cloke <clokep@users.noreply.github.com>2020-07-17 07:59:23 -0400
committerGitHub <noreply@github.com>2020-07-17 07:59:23 -0400
commit852930add765540c580378238ab03869a8c7530d (patch)
tree105fc715ef41f221871a12ba22704dc1dbddc4d7 /synapse/config/server.py
parentChange "unknown room ver" logging to warning. (#7881) (diff)
downloadsynapse-852930add765540c580378238ab03869a8c7530d.tar.xz
Add a default limit (of 100) to get/sync operations. (#7858)
Diffstat (limited to 'synapse/config/server.py')
-rw-r--r--synapse/config/server.py6
1 files changed, 4 insertions, 2 deletions
diff --git a/synapse/config/server.py b/synapse/config/server.py
index b6afa642ca..3586a7d491 100644
--- a/synapse/config/server.py
+++ b/synapse/config/server.py
@@ -207,7 +207,7 @@ class ServerConfig(Config):
         # errors when attempting to search for messages.
         self.enable_search = config.get("enable_search", True)
 
-        self.filter_timeline_limit = config.get("filter_timeline_limit", -1)
+        self.filter_timeline_limit = config.get("filter_timeline_limit", 100)
 
         # Whether we should block invites sent to users on this server
         # (other than those sent by local server admins)
@@ -693,7 +693,9 @@ class ServerConfig(Config):
         #gc_thresholds: [700, 10, 10]
 
         # Set the limit on the returned events in the timeline in the get
         # and sync operations. The default value is -1, means no upper limit.
         #
         #filter_timeline_limit: 5000
@@ -693,7 +693,9 @@ class ServerConfig(Config):
 
         # Set the limit on the returned events in the timeline in the get
-        # and sync operations. The default value is -1, means no upper limit.
+        # and sync operations. The default value is 100. -1 means no upper limit.
+        #
+        # Uncomment the following to increase the limit to 5000.
         #
         #filter_timeline_limit: 5000